@@ -8,6 +8,8 @@ import os
 from derrick.core.detector_report import DetectorReport
 from derrick.core.rigging import Rigging
 from derrick.detectors.image.node import NodeVersionDetector
+from derrick.detectors.general.image_repo import ImageRepoDetector
+from derrick.core.common import *
 
 PLATFORM = "NodeJs"
 
@@ -28,4 +30,12 @@ class NodejsRigging(Rigging):
         dr = DetectorReport()
         docker_node = dr.create_node("Dockerfile.j2")
         docker_node.register_detector(NodeVersionDetector())
+
+        if is_windows() is not True:
+            docker_compose_node = dr.create_node("docker-compose.yml.j2")
+            docker_compose_node.register_detector(ImageRepoDetector())
+
+            jenkins_file_node = dr.create_node("Jenkinsfile.j2")
+            jenkins_file_node.register_detector(ImageRepoDetector())
+
         return dr.generate_report()
